
# SPDX-FileCopyrightText: 2024-present Adam Fourney <adam.fourney@gmail.com>
#
# SPDX-License-Identifier: MIT
from typing import NamedTuple, List

class ITU_Prefix(NamedTuple):
    prefix: str
    country_name: str
    country_code: str

# Based on https://en.wikipedia.org/wiki/ITU_prefix#Allocation_table
ITU_PREFIXES = [
    ITU_Prefix("HB3Y", "Liechtenstein", "LI"),
    ITU_Prefix("HB0", "Liechtenstein", "LI"),
    ITU_Prefix("HBL", "Liechtenstein", "LI"),
    ITU_Prefix("SSA", "Egypt", "EG"),
    ITU_Prefix("SSB", "Egypt", "EG"),
    ITU_Prefix("SSC", "Egypt", "EG"),
    ITU_Prefix("SSD", "Egypt", "EG"),
    ITU_Prefix("SSE", "Egypt", "EG"),
    ITU_Prefix("SSF", "Egypt", "EG"),
    ITU_Prefix("SSG", "Egypt", "EG"),
    ITU_Prefix("SSH", "Egypt", "EG"),
    ITU_Prefix("SSI", "Egypt", "EG"),
    ITU_Prefix("SSJ", "Egypt", "EG"),
    ITU_Prefix("SSK", "Egypt", "EG"),
    ITU_Prefix("SSL", "Egypt", "EG"),
    ITU_Prefix("SSM", "Egypt", "EG"),
    ITU_Prefix("SSN", "Sudan", "SD"),
    ITU_Prefix("SSO", "Sudan", "SD"),
    ITU_Prefix("SSP", "Sudan", "SD"),
    ITU_Prefix("SSQ", "Sudan", "SD"),
    ITU_Prefix("SSR", "Sudan", "SD"),
    ITU_Prefix("SSS", "Sudan", "SD"),
    ITU_Prefix("SST", "Sudan", "SD"),
    ITU_Prefix("SSU", "Sudan", "SD"),
    ITU_Prefix("SSV", "Sudan", "SD"),
    ITU_Prefix("SSW", "Sudan", "SD"),
    ITU_Prefix("SSX", "Sudan", "SD"),
    ITU_Prefix("SSY", "Sudan", "SD"),
    ITU_Prefix("SSZ", "Sudan", "SD"),
    ITU_Prefix("3DA", "Eswatini", "SZ"),
    ITU_Prefix("3DB", "Eswatini", "SZ"),
    ITU_Prefix("3DC", "Eswatini", "SZ"),
    ITU_Prefix("3DD", "Eswatini", "SZ"),
    ITU_Prefix("3DE", "Eswatini", "SZ"),
    ITU_Prefix("3DF", "Eswatini", "SZ"),
    ITU_Prefix("3DG", "Eswatini", "SZ"),
    ITU_Prefix("3DH", "Eswatini", "SZ"),
    ITU_Prefix("3DI", "Eswatini", "SZ"),
    ITU_Prefix("3DJ", "Eswatini", "SZ"),
    ITU_Prefix("3DK", "Eswatini", "SZ"),
    ITU_Prefix("3DL", "Eswatini", "SZ"),
    ITU_Prefix("3DM", "Eswatini", "SZ"),
    ITU_Prefix("3DN", "Fiji", "FJ"),
    ITU_Prefix("3DO", "Fiji", "FJ"),
    ITU_Prefix("3DP", "Fiji", "FJ"),
    ITU_Prefix("3DQ", "Fiji", "FJ"),
    ITU_Prefix("3DR", "Fiji", "FJ"),
    ITU_Prefix("3DS", "Fiji", "FJ"),
    ITU_Prefix("3DT", "Fiji", "FJ"),
    ITU_Prefix("3DU", "Fiji", "FJ"),
    ITU_Prefix("3DV", "Fiji", "FJ"),
    ITU_Prefix("3DW", "Fiji", "FJ"),
    ITU_Prefix("3DX", "Fiji", "FJ"),
    ITU_Prefix("3DY", "Fiji", "FJ"),
    ITU_Prefix("3DZ", "Fiji", "FJ"),
    ITU_Prefix("AA", "United States", "US"),
    ITU_Prefix("AB", "United States", "US"),
    ITU_Prefix("AC", "United States", "US"),
    ITU_Prefix("AD", "United States", "US"),
    ITU_Prefix("AE", "United States", "US"),
    ITU_Prefix("AF", "United States", "US"),
    ITU_Prefix("AG", "United States", "US"),
    ITU_Prefix("AH", "United States", "US"),
    ITU_Prefix("AI", "United States", "US"),
    ITU_Prefix("AJ", "United States", "US"),
    ITU_Prefix("AK", "United States", "US"),
    ITU_Prefix("AL", "United States", "US"),
    ITU_Prefix("AM", "Spain", "ES"),
    ITU_Prefix("AN", "Spain", "ES"),
    ITU_Prefix("AO", "Spain", "ES"),
    ITU_Prefix("AP", "Pakistan", "PK"),
    ITU_Prefix("AQ", "Pakistan", "PK"),
    ITU_Prefix("AR", "Pakistan", "PK"),
    ITU_Prefix("AS", "Pakistan", "PK"),
    ITU_Prefix("AT", "India", "IN"),
    ITU_Prefix("AU", "India", "IN"),
    ITU_Prefix("AV", "India", "IN"),
    ITU_Prefix("AW", "India", "IN"),
    ITU_Prefix("AX", "Australia", "AU"),
    ITU_Prefix("AY", "Argentina", "AR"),
    ITU_Prefix("AZ", "Argentina", "AR"),
    ITU_Prefix("A2", "Botswana", "BW"),
    ITU_Prefix("A3", "Tonga", "TO"),
    ITU_Prefix("A4", "Oman", "OM"),
    ITU_Prefix("A5", "Bhutan", "BT"),
    ITU_Prefix("A6", "United Arab Emirates", "AE"),
    ITU_Prefix("A7", "Qatar", "QA"),
    ITU_Prefix("A8", "Liberia", "LR"),
    ITU_Prefix("A9", "Bahrain", "BH"),
    ITU_Prefix("BM", "Taiwan", "TW"),
    ITU_Prefix("BN", "Taiwan", "TW"),
    ITU_Prefix("BO", "Taiwan", "TW"),
    ITU_Prefix("BP", "Taiwan", "TW"),
    ITU_Prefix("BQ", "Taiwan", "TW"),
    ITU_Prefix("BU", "Taiwan", "TW"),
    ITU_Prefix("BV", "Taiwan", "TW"),
    ITU_Prefix("BW", "Taiwan", "TW"),
    ITU_Prefix("BX", "Taiwan", "TW"),
    ITU_Prefix("CA", "Chile", "CL"),
    ITU_Prefix("CB", "Chile", "CL"),
    ITU_Prefix("CC", "Chile", "CL"),
    ITU_Prefix("CD", "Chile", "CL"),
    ITU_Prefix("CE", "Chile", "CL"),
    ITU_Prefix("CF", "Canada", "CA"),
    ITU_Prefix("CG", "Canada", "CA"),
    ITU_Prefix("CH", "Canada", "CA"),
    ITU_Prefix("CI", "Canada", "CA"),
    ITU_Prefix("CJ", "Canada", "CA"),
    ITU_Prefix("CK", "Canada", "CA"),
    ITU_Prefix("CL", "Cuba", "CU"),
    ITU_Prefix("CM", "Cuba", "CU"),
    ITU_Prefix("CN", "Morocco", "MA"),
    ITU_Prefix("CO", "Cuba", "CU"),
    ITU_Prefix("CP", "Bolivia", "BO"),
    ITU_Prefix("CQ", "Portugal", "PT"),
    ITU_Prefix("CR", "Portugal", "PT"),
    ITU_Prefix("CS", "Portugal", "PT"),
    ITU_Prefix("CT", "Portugal", "PT"),
    ITU_Prefix("CU", "Portugal", "PT"),
    ITU_Prefix("CV", "Uruguay", "UY"),
    ITU_Prefix("CW", "Uruguay", "UY"),
    ITU_Prefix("CX", "Uruguay", "UY"),
    ITU_Prefix("CY", "Canada", "CA"),
    ITU_Prefix("CZ", "Canada", "CA"),
    ITU_Prefix("C2", "Nauru", "NR"),
    ITU_Prefix("C3", "Andorra", "AD"),
    ITU_Prefix("C4", "Cyprus", "CY"),
    ITU_Prefix("C5", "The Gambia", "GM"),
    ITU_Prefix("C6", "Bahamas", "BS"),
    ITU_Prefix("C7", "World Meteorological Organization", None),
    ITU_Prefix("C8", "Mozambique", "MZ"),
    ITU_Prefix("C9", "Mozambique", "MZ"),
    ITU_Prefix("DA", "Germany", "DE"),
    ITU_Prefix("DB", "Germany", "DE"),
    ITU_Prefix("DC", "Germany", "DE"),
    ITU_Prefix("DD", "Germany", "DE"),
    ITU_Prefix("DE", "Germany", "DE"),
    ITU_Prefix("DF", "Germany", "DE"),
    ITU_Prefix("DG", "Germany", "DE"),
    ITU_Prefix("DH", "Germany", "DE"),
    ITU_Prefix("DI", "Germany", "DE"),
    ITU_Prefix("DJ", "Germany", "DE"),
    ITU_Prefix("DK", "Germany", "DE"),
    ITU_Prefix("DL", "Germany", "DE"),
    ITU_Prefix("DM", "Germany", "DE"),
    ITU_Prefix("DN", "Germany", "DE"),
    ITU_Prefix("DO", "Germany", "DE"),
    ITU_Prefix("DP", "Germany", "DE"),
    ITU_Prefix("DQ", "Germany", "DE"),
    ITU_Prefix("DR", "Germany", "DE"),
    ITU_Prefix("DS", "South Korea", "KR"),
    ITU_Prefix("DT", "South Korea", "KR"),
    ITU_Prefix("DU", "Philippines", "PH"),
    ITU_Prefix("DV", "Philippines", "PH"),
    ITU_Prefix("DW", "Philippines", "PH"),
    ITU_Prefix("DX", "Philippines", "PH"),
    ITU_Prefix("DY", "Philippines", "PH"),
    ITU_Prefix("DZ", "Philippines", "PH"),
    ITU_Prefix("D2", "Angola", "AO"),
    ITU_Prefix("D3", "Angola", "AO"),
    ITU_Prefix("D4", "Cape Verde", "CV"),
    ITU_Prefix("D5", "Liberia", "LR"),
    ITU_Prefix("D6", "Comoros", "KM"),
    ITU_Prefix("D7", "South Korea", "KR"),
    ITU_Prefix("D8", "South Korea", "KR"),
    ITU_Prefix("D9", "South Korea", "KR"),
    ITU_Prefix("EA", "Spain", "ES"),
    ITU_Prefix("EB", "Spain", "ES"),
    ITU_Prefix("EC", "Spain", "ES"),
    ITU_Prefix("ED", "Spain", "ES"),
    ITU_Prefix("EE", "Spain", "ES"),
    ITU_Prefix("EF", "Spain", "ES"),
    ITU_Prefix("EG", "Spain", "ES"),
    ITU_Prefix("EH", "Spain", "ES"),
    ITU_Prefix("EI", "Ireland", "IE"),
    ITU_Prefix("EJ", "Ireland", "IE"),
    ITU_Prefix("EK", "Armenia", "AM"),
    ITU_Prefix("EL", "Liberia", "LR"),
    ITU_Prefix("EM", "Ukraine", "UA"),
    ITU_Prefix("EN", "Ukraine", "UA"),
    ITU_Prefix("EO", "Ukraine", "UA"),
    ITU_Prefix("EP", "Iran", "IR"),
    ITU_Prefix("EQ", "Iran", "IR"),
    ITU_Prefix("ER", "Moldova", "MD"),
    ITU_Prefix("ES", "Estonia", "EE"),
    ITU_Prefix("ET", "Ethiopia", "ET"),
    ITU_Prefix("EU", "Belarus", "BY"),
    ITU_Prefix("EV", "Belarus", "BY"),
    ITU_Prefix("EW", "Belarus", "BY"),
    ITU_Prefix("EX", "Kyrgyzstan", "KG"),
    ITU_Prefix("EY", "Tajikistan", "TJ"),
    ITU_Prefix("EZ", "Turkmenistan", "TM"),
    ITU_Prefix("E2", "Thailand", "TH"),
    ITU_Prefix("E3", "Eritrea", "ER"),
    ITU_Prefix("E4", "Palestinian Authority", "PS"),
    ITU_Prefix("E5", "Cook Islands", "CK"),
    ITU_Prefix("E7", "Bosnia-Herzegovina", "BA"),
    ITU_Prefix("HA", "Hungary", "HU"),
    ITU_Prefix("HB", "Switzerland", "CH"),
    ITU_Prefix("HC", "Ecuador", "EC"),
    ITU_Prefix("HD", "Ecuador", "EC"),
    ITU_Prefix("HE", "Switzerland", "CH"),
    ITU_Prefix("HF", "Poland", "PL"),
    ITU_Prefix("HG", "Hungary", "HU"),
    ITU_Prefix("HH", "Haiti", "HT"),
    ITU_Prefix("HI", "Dominican Republic", "DO"),
    ITU_Prefix("HJ", "Colombia", "CO"),
    ITU_Prefix("HK", "Colombia", "CO"),
    ITU_Prefix("HL", "South Korea", "KR"),
    ITU_Prefix("HM", "North Korea", "KP"),
    ITU_Prefix("HN", "Iraq", "IQ"),
    ITU_Prefix("HO", "Panama", "PA"),
    ITU_Prefix("HP", "Panama", "PA"),
    ITU_Prefix("HQ", "Honduras", "HN"),
    ITU_Prefix("HR", "Honduras", "HN"),
    ITU_Prefix("HS", "Thailand", "TH"),
    ITU_Prefix("HT", "Nicaragua", "NI"),
    ITU_Prefix("HU", "El Salvador", "SV"),
    ITU_Prefix("HV", "Vatican City", "VA"),
    ITU_Prefix("HW", "France", "FR"),
    ITU_Prefix("HX", "France", "FR"),
    ITU_Prefix("HY", "France", "FR"),
    ITU_Prefix("HZ", "Saudi Arabia", "SA"),
    ITU_Prefix("H2", "Cyprus", "CY"),
    ITU_Prefix("H3", "Panama", "PA"),
    ITU_Prefix("H4", "Solomon Islands", "SB"),
    ITU_Prefix("H6", "Nicaragua", "NI"),
    ITU_Prefix("H7", "Nicaragua", "NI"),
    ITU_Prefix("H8", "Panama", "PA"),
    ITU_Prefix("H9", "Panama", "PA"),
    ITU_Prefix("JA", "Japan", "JP"),
    ITU_Prefix("JB", "Japan", "JP"),
    ITU_Prefix("JC", "Japan", "JP"),
    ITU_Prefix("JD", "Japan", "JP"),
    ITU_Prefix("JE", "Japan", "JP"),
    ITU_Prefix("JF", "Japan", "JP"),
    ITU_Prefix("JG", "Japan", "JP"),
    ITU_Prefix("JH", "Japan", "JP"),
    ITU_Prefix("JI", "Japan", "JP"),
    ITU_Prefix("JJ", "Japan", "JP"),
    ITU_Prefix("JK", "Japan", "JP"),
    ITU_Prefix("JL", "Japan", "JP"),
    ITU_Prefix("JM", "Japan", "JP"),
    ITU_Prefix("JN", "Japan", "JP"),
    ITU_Prefix("JO", "Japan", "JP"),
    ITU_Prefix("JP", "Japan", "JP"),
    ITU_Prefix("JQ", "Japan", "JP"),
    ITU_Prefix("JR", "Japan", "JP"),
    ITU_Prefix("JS", "Japan", "JP"),
    ITU_Prefix("JT", "Mongolia", "MN"),
    ITU_Prefix("JU", "Mongolia", "MN"),
    ITU_Prefix("JV", "Mongolia", "MN"),
    ITU_Prefix("JW", "Norway", "NO"),
    ITU_Prefix("JX", "Norway", "NO"),
    ITU_Prefix("JY", "Jordan", "JO"),
    ITU_Prefix("JZ", "Indonesia", "ID"),
    ITU_Prefix("J2", "Djibouti", "DJ"),
    ITU_Prefix("J3", "Grenada", "GD"),
    ITU_Prefix("J4", "Greece", "GR"),
    ITU_Prefix("J5", "Guinea-Bissau", "GW"),
    ITU_Prefix("J6", "Saint Lucia", "LC"),
    ITU_Prefix("J7", "Dominica", "DM"),
    ITU_Prefix("J8", "Saint Vincent and the Grenadines", "VC"),
    ITU_Prefix("LA", "Norway", "NO"),
    ITU_Prefix("LB", "Norway", "NO"),
    ITU_Prefix("LC", "Norway", "NO"),
    ITU_Prefix("LD", "Norway", "NO"),
    ITU_Prefix("LE", "Norway", "NO"),
    ITU_Prefix("LF", "Norway", "NO"),
    ITU_Prefix("LG", "Norway", "NO"),
    ITU_Prefix("LH", "Norway", "NO"),
    ITU_Prefix("LI", "Norway", "NO"),
    ITU_Prefix("LJ", "Norway", "NO"),
    ITU_Prefix("LK", "Norway", "NO"),
    ITU_Prefix("LL", "Norway", "NO"),
    ITU_Prefix("LM", "Norway", "NO"),
    ITU_Prefix("LN", "Norway", "NO"),
    ITU_Prefix("LO", "Argentina", "AR"),
    ITU_Prefix("LP", "Argentina", "AR"),
    ITU_Prefix("LQ", "Argentina", "AR"),
    ITU_Prefix("LR", "Argentina", "AR"),
    ITU_Prefix("LS", "Argentina", "AR"),
    ITU_Prefix("LT", "Argentina", "AR"),
    ITU_Prefix("LU", "Argentina", "AR"),
    ITU_Prefix("LV", "Argentina", "AR"),
    ITU_Prefix("LW", "Argentina", "AR"),
    ITU_Prefix("LX", "Luxembourg", "LU"),
    ITU_Prefix("LY", "Lithuania", "LT"),
    ITU_Prefix("LZ", "Bulgaria", "BG"),
    ITU_Prefix("L2", "Argentina", "AR"),
    ITU_Prefix("L3", "Argentina", "AR"),
    ITU_Prefix("L4", "Argentina", "AR"),
    ITU_Prefix("L5", "Argentina", "AR"),
    ITU_Prefix("L6", "Argentina", "AR"),
    ITU_Prefix("L7", "Argentina", "AR"),
    ITU_Prefix("L8", "Argentina", "AR"),
    ITU_Prefix("L9", "Argentina", "AR"),
    ITU_Prefix("OA", "Peru", "PE"),
    ITU_Prefix("OB", "Peru", "PE"),
    ITU_Prefix("OC", "Peru", "PE"),
    ITU_Prefix("OD", "Lebanon", "LB"),
    ITU_Prefix("OE", "Austria", "AT"),
    ITU_Prefix("OF", "Finland", "FI"),
    ITU_Prefix("OG", "Finland", "FI"),
    ITU_Prefix("OH", "Finland", "FI"),
    ITU_Prefix("OI", "Finland", "FI"),
    ITU_Prefix("OJ", "Finland", "FI"),
    ITU_Prefix("OK", "Czech Republic", "CZ"),
    ITU_Prefix("OL", "Czech Republic", "CZ"),
    ITU_Prefix("OM", "Slovakia", "SK"),
    ITU_Prefix("ON", "Belgium", "BE"),
    ITU_Prefix("OO", "Belgium", "BE"),
    ITU_Prefix("OP", "Belgium", "BE"),
    ITU_Prefix("OQ", "Belgium", "BE"),
    ITU_Prefix("OR", "Belgium", "BE"),
    ITU_Prefix("OS", "Belgium", "BE"),
    ITU_Prefix("OT", "Belgium", "BE"),
    ITU_Prefix("OU", "Denmark", "DK"),
    ITU_Prefix("OV", "Denmark", "DK"),
    ITU_Prefix("OW", "Denmark", "DK"),
    ITU_Prefix("OX", "Denmark", "DK"),
    ITU_Prefix("OY", "Denmark", "DK"),
    ITU_Prefix("OZ", "Denmark", "DK"),
    ITU_Prefix("PA", "Netherlands", "NL"),
    ITU_Prefix("PB", "Netherlands", "NL"),
    ITU_Prefix("PC", "Netherlands", "NL"),
    ITU_Prefix("PD", "Netherlands", "NL"),
    ITU_Prefix("PE", "Netherlands", "NL"),
    ITU_Prefix("PF", "Netherlands", "NL"),
    ITU_Prefix("PG", "Netherlands", "NL"),
    ITU_Prefix("PH", "Netherlands", "NL"),
    ITU_Prefix("PI", "Netherlands", "NL"),
    ITU_Prefix("PJ", "Netherlands", "NL"),
    ITU_Prefix("PK", "Indonesia", "ID"),
    ITU_Prefix("PL", "Indonesia", "ID"),
    ITU_Prefix("PM", "Indonesia", "ID"),
    ITU_Prefix("PN", "Indonesia", "ID"),
    ITU_Prefix("PO", "Indonesia", "ID"),
    ITU_Prefix("PP", "Brazil", "BR"),
    ITU_Prefix("PQ", "Brazil", "BR"),
    ITU_Prefix("PR", "Brazil", "BR"),
    ITU_Prefix("PS", "Brazil", "BR"),
    ITU_Prefix("PT", "Brazil", "BR"),
    ITU_Prefix("PU", "Brazil", "BR"),
    ITU_Prefix("PV", "Brazil", "BR"),
    ITU_Prefix("PW", "Brazil", "BR"),
    ITU_Prefix("PX", "Brazil", "BR"),
    ITU_Prefix("PY", "Brazil", "BR"),
    ITU_Prefix("PZ", "Suriname", "SR"),
    ITU_Prefix("P2", "Papua New Guinea", "PG"),
    ITU_Prefix("P3", "Cyprus", "CY"),
    ITU_Prefix("P4", "Aruba", "AW"),
    ITU_Prefix("P5", "North Korea", "KP"),
    ITU_Prefix("P6", "North Korea", "KP"),
    ITU_Prefix("P7", "North Korea", "KP"),
    ITU_Prefix("P8", "North Korea", "KP"),
    ITU_Prefix("P9", "North Korea", "KP"),
    ITU_Prefix("SA", "Sweden", "SE"),
    ITU_Prefix("SB", "Sweden", "SE"),
    ITU_Prefix("SC", "Sweden", "SE"),
    ITU_Prefix("SD", "Sweden", "SE"),
    ITU_Prefix("SE", "Sweden", "SE"),
    ITU_Prefix("SF", "Sweden", "SE"),
    ITU_Prefix("SG", "Sweden", "SE"),
    ITU_Prefix("SH", "Sweden", "SE"),
    ITU_Prefix("SI", "Sweden", "SE"),
    ITU_Prefix("SJ", "Sweden", "SE"),
    ITU_Prefix("SK", "Sweden", "SE"),
    ITU_Prefix("SL", "Sweden", "SE"),
    ITU_Prefix("SM", "Sweden", "SE"),
    ITU_Prefix("SN", "Poland", "PL"),
    ITU_Prefix("SO", "Poland", "PL"),
    ITU_Prefix("SP", "Poland", "PL"),
    ITU_Prefix("SQ", "Poland", "PL"),
    ITU_Prefix("SR", "Poland", "PL"),
    ITU_Prefix("ST", "Sudan", "SD"),
    ITU_Prefix("SU", "Egypt", "EG"),
    ITU_Prefix("SV", "Greece", "GR"),
    ITU_Prefix("SW", "Greece", "GR"),
    ITU_Prefix("SX", "Greece", "GR"),
    ITU_Prefix("SY", "Greece", "GR"),
    ITU_Prefix("SZ", "Greece", "GR"),
    ITU_Prefix("S2", "Bangladesh", "BD"),
    ITU_Prefix("S3", "Bangladesh", "BD"),
    ITU_Prefix("S5", "Slovenia", "SI"),
    ITU_Prefix("S6", "Singapore", "SG"),
    ITU_Prefix("S7", "Seychelles", "SC"),
    ITU_Prefix("S8", "South Africa", "ZA"),
    ITU_Prefix("S9", "Sao Tome and Principe", "ST"),
    ITU_Prefix("TA", "Turkey", "TR"),
    ITU_Prefix("TB", "Turkey", "TR"),
    ITU_Prefix("TC", "Turkey", "TR"),
    ITU_Prefix("TD", "Guatemala", "GT"),
    ITU_Prefix("TE", "Costa Rica", "CR"),
    ITU_Prefix("TF", "Iceland", "IS"),
    ITU_Prefix("TG", "Guatemala", "GT"),
    ITU_Prefix("TH", "France", "FR"),
    ITU_Prefix("TI", "Costa Rica", "CR"),
    ITU_Prefix("TJ", "Cameroon", "CM"),
    ITU_Prefix("TK", "France", "FR"),
    ITU_Prefix("TL", "Central African Republic", "CF"),
    ITU_Prefix("TM", "France", "FR"),
    ITU_Prefix("TN", "Congo", "CG"),
    ITU_Prefix("TO", "France", "FR"),
    ITU_Prefix("TP", "France", "FR"),
    ITU_Prefix("TQ", "France", "FR"),
    ITU_Prefix("TR", "Gabon", "GA"),
    ITU_Prefix("TS", "Tunisia", "TN"),
    ITU_Prefix("TT", "Chad", "TD"),
    ITU_Prefix("TU", "Cote d'Ivoire", "CI"),
    ITU_Prefix("TV", "France", "FR"),
    ITU_Prefix("TW", "France", "FR"),
    ITU_Prefix("TX", "France", "FR"),
    ITU_Prefix("TY", "Benin", "BJ"),
    ITU_Prefix("TZ", "Mali", "ML"),
    ITU_Prefix("T2", "Tuvalu", "TV"),
    ITU_Prefix("T3", "Kiribati", "KI"),
    ITU_Prefix("T4", "Cuba", "CU"),
    ITU_Prefix("T5", "Somalia", "SO"),
    ITU_Prefix("T6", "Afghanistan", "AF"),
    ITU_Prefix("T7", "San Marino", "SM"),
    ITU_Prefix("T8", "Palau", "PW"),
    ITU_Prefix("T9", "Bosnia-Herzegovina", "BA"),
    ITU_Prefix("UA", "Russia", "RU"),
    ITU_Prefix("UB", "Russia", "RU"),
    ITU_Prefix("UC", "Russia", "RU"),
    ITU_Prefix("UD", "Russia", "RU"),
    ITU_Prefix("UE", "Russia", "RU"),
    ITU_Prefix("UF", "Russia", "RU"),
    ITU_Prefix("UG", "Russia", "RU"),
    ITU_Prefix("UH", "Russia", "RU"),
    ITU_Prefix("UI", "Russia", "RU"),
    ITU_Prefix("UJ", "Uzbekistan", "UZ"),
    ITU_Prefix("UK", "Uzbekistan", "UZ"),
    ITU_Prefix("UL", "Uzbekistan", "UZ"),
    ITU_Prefix("UM", "Uzbekistan", "UZ"),
    ITU_Prefix("UN", "Kazakhstan", "KZ"),
    ITU_Prefix("UO", "Kazakhstan", "KZ"),
    ITU_Prefix("UP", "Kazakhstan", "KZ"),
    ITU_Prefix("UQ", "Kazakhstan", "KZ"),
    ITU_Prefix("UR", "Ukraine", "UA"),
    ITU_Prefix("US", "Ukraine", "UA"),
    ITU_Prefix("UT", "Ukraine", "UA"),
    ITU_Prefix("UU", "Ukraine", "UA"),
    ITU_Prefix("UV", "Ukraine", "UA"),
    ITU_Prefix("UW", "Ukraine", "UA"),
    ITU_Prefix("UX", "Ukraine", "UA"),
    ITU_Prefix("UY", "Ukraine", "UA"),
    ITU_Prefix("UZ", "Ukraine", "UA"),
    ITU_Prefix("VA", "Canada", "CA"),
    ITU_Prefix("VB", "Canada", "CA"),
    ITU_Prefix("VC", "Canada", "CA"),
    ITU_Prefix("VD", "Canada", "CA"),
    ITU_Prefix("VE", "Canada", "CA"),
    ITU_Prefix("VF", "Canada", "CA"),
    ITU_Prefix("VG", "Canada", "CA"),
    ITU_Prefix("VH", "Australia", "AU"),
    ITU_Prefix("VI", "Australia", "AU"),
    ITU_Prefix("VJ", "Australia", "AU"),
    ITU_Prefix("VK", "Australia", "AU"),
    ITU_Prefix("VL", "Australia", "AU"),
    ITU_Prefix("VM", "Australia", "AU"),
    ITU_Prefix("VN", "Australia", "AU"),
    ITU_Prefix("VO", "Canada", "CA"),
    ITU_Prefix("VP", "United Kingdom", "GB"),
    ITU_Prefix("VQ", "United Kingdom", "GB"),
    ITU_Prefix("VR", "Hong Kong", "HK"),
    ITU_Prefix("VS", "United Kingdom", "GB"),
    ITU_Prefix("VT", "India", "IN"),
    ITU_Prefix("VU", "India", "IN"),
    ITU_Prefix("VV", "India", "IN"),
    ITU_Prefix("VW", "India", "IN"),
    ITU_Prefix("VX", "Canada", "CA"),
    ITU_Prefix("VY", "Canada", "CA"),
    ITU_Prefix("VZ", "Australia", "AU"),
    ITU_Prefix("V2", "Antigua and Barbuda", "AG"),
    ITU_Prefix("V3", "Belize", "BZ"),
    ITU_Prefix("V4", "Saint Kitts and Nevis", "KN"),
    ITU_Prefix("V5", "Namibia", "NA"),
    ITU_Prefix("V6", "Federated States of Micronesia", "FM"),
    ITU_Prefix("V7", "Marshall Islands", "MH"),
    ITU_Prefix("V8", "Brunei", "BN"),
    ITU_Prefix("XA", "Mexico", "MX"),
    ITU_Prefix("XB", "Mexico", "MX"),
    ITU_Prefix("XC", "Mexico", "MX"),
    ITU_Prefix("XD", "Mexico", "MX"),
    ITU_Prefix("XE", "Mexico", "MX"),
    ITU_Prefix("XF", "Mexico", "MX"),
    ITU_Prefix("XG", "Mexico", "MX"),
    ITU_Prefix("XH", "Mexico", "MX"),
    ITU_Prefix("XI", "Mexico", "MX"),
    ITU_Prefix("XJ", "Canada", "CA"),
    ITU_Prefix("XK", "Canada", "CA"),
    ITU_Prefix("XL", "Canada", "CA"),
    ITU_Prefix("XM", "Canada", "CA"),
    ITU_Prefix("XN", "Canada", "CA"),
    ITU_Prefix("XO", "Canada", "CA"),
    ITU_Prefix("XP", "Denmark", "DK"),
    ITU_Prefix("XQ", "Chile", "CL"),
    ITU_Prefix("XR", "Chile", "CL"),
    ITU_Prefix("XS", "People's Republic of China", "CN"),
    ITU_Prefix("XT", "Burkina Faso", "BF"),
    ITU_Prefix("XU", "Cambodia", "KH"),
    ITU_Prefix("XV", "Vietnam", "VN"),
    ITU_Prefix("XW", "Laos", "LA"),
    ITU_Prefix("XX", "Macao", "MO"),
    ITU_Prefix("XY", "Myanmar", "MM"),
    ITU_Prefix("XZ", "Myanmar", "MM"),
    ITU_Prefix("YA", "Afghanistan", "AF"),
    ITU_Prefix("YB", "Indonesia", "ID"),
    ITU_Prefix("YC", "Indonesia", "ID"),
    ITU_Prefix("YD", "Indonesia", "ID"),
    ITU_Prefix("YE", "Indonesia", "ID"),
    ITU_Prefix("YF", "Indonesia", "ID"),
    ITU_Prefix("YG", "Indonesia", "ID"),
    ITU_Prefix("YH", "Indonesia", "ID"),
    ITU_Prefix("YI", "Iraq", "IQ"),
    ITU_Prefix("YJ", "Vanuatu", "VU"),
    ITU_Prefix("YK", "Syria", "SY"),
    ITU_Prefix("YL", "Latvia", "LV"),
    ITU_Prefix("YM", "Turkey", "TR"),
    ITU_Prefix("YN", "Nicaragua", "NI"),
    ITU_Prefix("YO", "Romania", "RO"),
    ITU_Prefix("YP", "Romania", "RO"),
    ITU_Prefix("YQ", "Romania", "RO"),
    ITU_Prefix("YR", "Romania", "RO"),
    ITU_Prefix("YS", "El Salvador", "SV"),
    ITU_Prefix("YT", "Serbia", "RS"),
    ITU_Prefix("YU", "Serbia", "RS"),
    ITU_Prefix("YV", "Venezuela", "VE"),
    ITU_Prefix("YW", "Venezuela", "VE"),
    ITU_Prefix("YX", "Venezuela", "VE"),
    ITU_Prefix("YY", "Venezuela", "VE"),
    ITU_Prefix("Y2", "Germany", "DE"),
    ITU_Prefix("Y3", "Germany", "DE"),
    ITU_Prefix("Y4", "Germany", "DE"),
    ITU_Prefix("Y5", "Germany", "DE"),
    ITU_Prefix("Y6", "Germany", "DE"),
    ITU_Prefix("Y7", "Germany", "DE"),
    ITU_Prefix("Y8", "Germany", "DE"),
    ITU_Prefix("Y9", "Germany", "DE"),
    ITU_Prefix("ZA", "Albania", "AL"),
    ITU_Prefix("ZB", "United Kingdom", "GB"),
    ITU_Prefix("ZC", "United Kingdom", "GB"),
    ITU_Prefix("ZD", "United Kingdom", "GB"),
    ITU_Prefix("ZE", "United Kingdom", "GB"),
    ITU_Prefix("ZF", "United Kingdom", "GB"),
    ITU_Prefix("ZG", "United Kingdom", "GB"),
    ITU_Prefix("ZH", "United Kingdom", "GB"),
    ITU_Prefix("ZI", "United Kingdom", "GB"),
    ITU_Prefix("ZJ", "United Kingdom", "GB"),
    ITU_Prefix("ZK", "New Zealand", "NZ"),
    ITU_Prefix("ZL", "New Zealand", "NZ"),
    ITU_Prefix("ZM", "New Zealand", "NZ"),
    ITU_Prefix("ZN", "United Kingdom", "GB"),
    ITU_Prefix("ZO", "United Kingdom", "GB"),
    ITU_Prefix("ZP", "Paraguay", "PY"),
    ITU_Prefix("ZQ", "United Kingdom", "GB"),
    ITU_Prefix("ZR", "South Africa", "ZA"),
    ITU_Prefix("ZS", "South Africa", "ZA"),
    ITU_Prefix("ZT", "South Africa", "ZA"),
    ITU_Prefix("ZU", "South Africa", "ZA"),
    ITU_Prefix("ZV", "Brazil", "BR"),
    ITU_Prefix("ZW", "Brazil", "BR"),
    ITU_Prefix("ZX", "Brazil", "BR"),
    ITU_Prefix("ZY", "Brazil", "BR"),
    ITU_Prefix("ZZ", "Brazil", "BR"),
    ITU_Prefix("Z2", "Zimbabwe", "ZW"),
    ITU_Prefix("Z3", "North Macedonia", "MK"),
    ITU_Prefix("Z8", "South Sudan", "SS"),
    ITU_Prefix("3A", "Monaco", "MC"),
    ITU_Prefix("3B", "Mauritius", "MU"),
    ITU_Prefix("3C", "Equatorial Guinea", "GQ"),
    ITU_Prefix("3E", "Panama", "PA"),
    ITU_Prefix("3F", "Panama", "PA"),
    ITU_Prefix("3G", "Chile", "CL"),
    ITU_Prefix("3H", "People's Republic of China", "CN"),
    ITU_Prefix("3I", "People's Republic of China", "CN"),
    ITU_Prefix("3J", "People's Republic of China", "CN"),
    ITU_Prefix("3K", "People's Republic of China", "CN"),
    ITU_Prefix("3L", "People's Republic of China", "CN"),
    ITU_Prefix("3M", "People's Republic of China", "CN"),
    ITU_Prefix("3N", "People's Republic of China", "CN"),
    ITU_Prefix("3O", "People's Republic of China", "CN"),
    ITU_Prefix("3P", "People's Republic of China", "CN"),
    ITU_Prefix("3Q", "People's Republic of China", "CN"),
    ITU_Prefix("3R", "People's Republic of China", "CN"),
    ITU_Prefix("3S", "People's Republic of China", "CN"),
    ITU_Prefix("3T", "People's Republic of China", "CN"),
    ITU_Prefix("3U", "People's Republic of China", "CN"),
    ITU_Prefix("3V", "Tunisia", "TN"),
    ITU_Prefix("3W", "Vietnam", "VN"),
    ITU_Prefix("3X", "Guinea", "GN"),
    ITU_Prefix("3Y", "Norway", "NO"),
    ITU_Prefix("3Z", "Poland", "PL"),
    ITU_Prefix("4A", "Mexico", "MX"),
    ITU_Prefix("4B", "Mexico", "MX"),
    ITU_Prefix("4C", "Mexico", "MX"),
    ITU_Prefix("4D", "Philippines", "PH"),
    ITU_Prefix("4E", "Philippines", "PH"),
    ITU_Prefix("4F", "Philippines", "PH"),
    ITU_Prefix("4G", "Philippines", "PH"),
    ITU_Prefix("4H", "Philippines", "PH"),
    ITU_Prefix("4I", "Philippines", "PH"),
    ITU_Prefix("4J", "Azerbaijan", "AZ"),
    ITU_Prefix("4K", "Azerbaijan", "AZ"),
    ITU_Prefix("4L", "Georgia", "GE"),
    ITU_Prefix("4M", "Venezuela", "VE"),
    ITU_Prefix("4O", "Montenegro", "ME"),
    ITU_Prefix("4P", "Sri Lanka", "LK"),
    ITU_Prefix("4Q", "Sri Lanka", "LK"),
    ITU_Prefix("4R", "Sri Lanka", "LK"),
    ITU_Prefix("4S", "Sri Lanka", "LK"),
    ITU_Prefix("4T", "Peru", "PE"),
    ITU_Prefix("4U", "United Nations", None),
    ITU_Prefix("4V", "Haiti", "HT"),
    ITU_Prefix("4W", "East Timor", "TL"),
    ITU_Prefix("4X", "Israel", "IL"),
    ITU_Prefix("4Y", "International Civil Aviation Organization", None),
    ITU_Prefix("4Z", "Israel", "IL"),
    ITU_Prefix("5A", "Libya", "LY"),
    ITU_Prefix("5B", "Cyprus", "CY"),
    ITU_Prefix("5C", "Morocco", "MA"),
    ITU_Prefix("5D", "Morocco", "MA"),
    ITU_Prefix("5E", "Morocco", "MA"),
    ITU_Prefix("5F", "Morocco", "MA"),
    ITU_Prefix("5G", "Morocco", "MA"),
    ITU_Prefix("5H", "Tanzania", "TZ"),
    ITU_Prefix("5I", "Tanzania", "TZ"),
    ITU_Prefix("5J", "Colombia", "CO"),
    ITU_Prefix("5K", "Colombia", "CO"),
    ITU_Prefix("5L", "Liberia", "LR"),
    ITU_Prefix("5M", "Liberia", "LR"),
    ITU_Prefix("5N", "Nigeria", "NG"),
    ITU_Prefix("5O", "Nigeria", "NG"),
    ITU_Prefix("5P", "Denmark", "DK"),
    ITU_Prefix("5Q", "Denmark", "DK"),
    ITU_Prefix("5R", "Madagascar", "MG"),
    ITU_Prefix("5S", "Madagascar", "MG"),
    ITU_Prefix("5T", "Mauritania", "MR"),
    ITU_Prefix("5U", "Niger", "NG"),
    ITU_Prefix("5V", "Togo", "TG"),
    ITU_Prefix("5W", "Western Samoa", "WS"),
    ITU_Prefix("5X", "Uganda", "UG"),
    ITU_Prefix("5Y", "Kenya", "KE"),
    ITU_Prefix("5Z", "Kenya", "KE"),
    ITU_Prefix("6A", "Egypt", "EG"),
    ITU_Prefix("6B", "Egypt", "EG"),
    ITU_Prefix("6C", "Syria", "SY"),
    ITU_Prefix("6D", "Mexico", "MX"),
    ITU_Prefix("6E", "Mexico", "MX"),
    ITU_Prefix("6F", "Mexico", "MX"),
    ITU_Prefix("6G", "Mexico", "MX"),
    ITU_Prefix("6H", "Mexico", "MX"),
    ITU_Prefix("6I", "Mexico", "MX"),
    ITU_Prefix("6J", "Mexico", "MX"),
    ITU_Prefix("6K", "South Korea", "KR"),
    ITU_Prefix("6L", "South Korea", "KR"),
    ITU_Prefix("6M", "South Korea", "KR"),
    ITU_Prefix("6N", "South Korea", "KR"),
    ITU_Prefix("6O", "Somalia", "SO"),
    ITU_Prefix("6P", "Pakistan", "PK"),
    ITU_Prefix("6Q", "Pakistan", "PK"),
    ITU_Prefix("6R", "Pakistan", "PK"),
    ITU_Prefix("6S", "Pakistan", "PK"),
    ITU_Prefix("6T", "Sudan", "SD"),
    ITU_Prefix("6U", "Sudan", "SD"),
    ITU_Prefix("6V", "Senegal", "SN"),
    ITU_Prefix("6W", "Senegal", "SN"),
    ITU_Prefix("6X", "Madagascar", "MG"),
    ITU_Prefix("6Y", "Jamaica", "JM"),
    ITU_Prefix("6Z", "Liberia", "LR"),
    ITU_Prefix("7A", "Indonesia", "ID"),
    ITU_Prefix("7B", "Indonesia", "ID"),
    ITU_Prefix("7C", "Indonesia", "ID"),
    ITU_Prefix("7D", "Indonesia", "ID"),
    ITU_Prefix("7E", "Indonesia", "ID"),
    ITU_Prefix("7F", "Indonesia", "ID"),
    ITU_Prefix("7G", "Indonesia", "ID"),
    ITU_Prefix("7H", "Indonesia", "ID"),
    ITU_Prefix("7I", "Indonesia", "ID"),
    ITU_Prefix("7J", "Japan", "JP"),
    ITU_Prefix("7K", "Japan", "JP"),
    ITU_Prefix("7L", "Japan", "JP"),
    ITU_Prefix("7M", "Japan", "JP"),
    ITU_Prefix("7N", "Japan", "JP"),
    ITU_Prefix("7O", "Yemen", "YE"),
    ITU_Prefix("7P", "Lesotho", "LS"),
    ITU_Prefix("7Q", "Malawi", "MW"),
    ITU_Prefix("7R", "Algeria", "DZ"),
    ITU_Prefix("7S", "Sweden", "SE"),
    ITU_Prefix("7T", "Algeria", "DZ"),
    ITU_Prefix("7U", "Algeria", "DZ"),
    ITU_Prefix("7V", "Algeria", "DZ"),
    ITU_Prefix("7W", "Algeria", "DZ"),
    ITU_Prefix("7X", "Algeria", "DZ"),
    ITU_Prefix("7Y", "Algeria", "DZ"),
    ITU_Prefix("7Z", "Saudi Arabia", "SA"),
    ITU_Prefix("8A", "Indonesia", "ID"),
    ITU_Prefix("8B", "Indonesia", "ID"),
    ITU_Prefix("8C", "Indonesia", "ID"),
    ITU_Prefix("8D", "Indonesia", "ID"),
    ITU_Prefix("8E", "Indonesia", "ID"),
    ITU_Prefix("8F", "Indonesia", "ID"),
    ITU_Prefix("8G", "Indonesia", "ID"),
    ITU_Prefix("8H", "Indonesia", "ID"),
    ITU_Prefix("8I", "Indonesia", "ID"),
    ITU_Prefix("8J", "Japan", "JP"),
    ITU_Prefix("8K", "Japan", "JP"),
    ITU_Prefix("8L", "Japan", "JP"),
    ITU_Prefix("8M", "Japan", "JP"),
    ITU_Prefix("8N", "Japan", "JP"),
    ITU_Prefix("8O", "Botswana", "BW"),
    ITU_Prefix("8P", "Barbados", "BB"),
    ITU_Prefix("8Q", "Maldives", "MV"),
    ITU_Prefix("8R", "Guyana", "GY"),
    ITU_Prefix("8S", "Sweden", "SE"),
    ITU_Prefix("8T", "India", "IN"),
    ITU_Prefix("8U", "India", "IN"),
    ITU_Prefix("8V", "India", "IN"),
    ITU_Prefix("8W", "India", "IN"),
    ITU_Prefix("8X", "India", "IN"),
    ITU_Prefix("8Y", "India", "IN"),
    ITU_Prefix("8Z", "Saudi Arabia", "SA"),
    ITU_Prefix("9A", "Croatia", "HR"),
    ITU_Prefix("9B", "Iran", "IR"),
    ITU_Prefix("9C", "Iran", "IR"),
    ITU_Prefix("9D", "Iran", "IR"),
    ITU_Prefix("9E", "Ethiopia", "ET"),
    ITU_Prefix("9F", "Ethiopia", "ET"),
    ITU_Prefix("9G", "Ghana", "GH"),
    ITU_Prefix("9H", "Malta", "MT"),
    ITU_Prefix("9I", "Zambia", "ZM"),
    ITU_Prefix("9J", "Zambia", "ZM"),
    ITU_Prefix("9K", "Kuwait", "KW"),
    ITU_Prefix("9L", "Sierra Leone", "SL"),
    ITU_Prefix("9M", "Malaysia", "MY"),
    ITU_Prefix("9N", "Nepal", "NP"),
    ITU_Prefix("9O", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9P", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9Q", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9R", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9S", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9T", "Democratic Republic of the Congo", "CG"),
    ITU_Prefix("9U", "Burundi", "BI"),
    ITU_Prefix("9V", "Singapore", "SG"),
    ITU_Prefix("9W", "Malaysia", "MY"),
    ITU_Prefix("9X", "Rwanda", "RW"),
    ITU_Prefix("9Y", "Trinidad and Tobago", "TT"),
    ITU_Prefix("9Z", "Trinidad and Tobago", "TT"),
    ITU_Prefix("B", "China", "CN"),
    ITU_Prefix("F", "France", "FR"),
    ITU_Prefix("G", "United Kingdom", "GB"),
    ITU_Prefix("I", "Italy", "IT"),
    ITU_Prefix("K", "United States", "US"),
    ITU_Prefix("M", "United Kingdom", "GB"),
    ITU_Prefix("N", "United States", "US"),
    ITU_Prefix("R", "Russia", "RU"),
    ITU_Prefix("W", "United States", "US"),
    ITU_Prefix("2", "United Kingdom", "GB"),
]

def call_sign_to_country(call_sign: str) -> ITU_Prefix|None:
    """
    Determine which country likely issued a given call sign. 
    Returns an ITU_Prefix record, or None (if no match was found)
    """
    call_sign = call_sign.strip().upper()
    for record in ITU_PREFIXES:
        if call_sign.startswith(record.prefix):
            return record
    return None

def prefix_to_countries(prefix: str) -> List[ITU_Prefix]:
    """
    Given a prefix, determine which country or countries might issue 
    call signs starting with that prefix. For "A" could be the 
    United States, Spain, Pakistan, etc. Whereas "K" is just the United
    States, and "CF" is Canada.
    Returns a list of ITU_Prefix records.
    """ 
    results: List[ITU_Prefix] = []
    prefix = prefix.strip().upper()
    if len(prefix) < 1 or len(prefix) > 4: 
        raise ValueError("Prefixes sould be 0-4 character.")
    for record in ITU_PREFIXES:
        if record.prefix.startswith(prefix):
            results.append(record)
    return results

def country_to_prefixes(country_code: str) -> List[ITU_Prefix]:
    """
    Given an ISO 3166-1 alpha-2 (two letter) country code, determine which 
    ITU prefixes that country might use for call signs. For example the "US"
    could issue call signs beginning with "AA-AL", "K", "N", or "W".
    Returns a list of ITU_Prefix records.
    """ 
    results: List[ITU_Prefix] = []
    country_code = country_code.strip()
    if len(country_code) != 2:
        raise ValueError("'{country_code}' sould be a ISO 3166-1 alpha-2 (two letter) country code.")
    country_code = country_code.upper()
    for record in ITU_PREFIXES:
        if record.country_code == country_code:
            results.append(record)
    return results
